def CleverClean(text):
    """
    A preprocessor to convert all letters to lower case, and to remove all punctuations and digits from the text.  
    
    Parameters
    ----------
    text : pandas.series
        Input a pandas series of text / strings
    
    Returns
    -------
    str
        A long string containing the cleaned of version of all text
    
    Examples
    --------
    >>> sample_text = pandas.Series('Apple is MY favorite!')
    >>> CleverClean(sample_text)
    'apple is my favorite'
    
    """
    #importing string and pandas package package
    import string
    import pandas as pd
    
    #Checking if correct inputs are given 
    if not pd.api.types.is_string_dtype(text):
        raise TypeError("Input 'text' should be a panda series containing only strings")
    
    #combining strings from the panda series to one large string 
    all_strings=''
    for i in text:
        all_strings+=str(i)
        all_strings+=" "

    #coverting strings to lower case
    text_low = all_strings.lower() 

    #removing all the digits from text
    text_low_noDigits = ''.join([i for i in text_low if not i.isdigit()])

    #removing all the punctuation from text using a for loop 
    prepro_text = "" #storing the complete preprocessed text in this variable 
    for i in text_low_noDigits:
        if i not in string.punctuation:
            prepro_text+=i
    
    #returning the text 
    return prepro_text



def CleverWordCloud(text, CleverStop, max_w):
  
    """
    This function generates a word cloud with customized stopwords and max words included. 
    
    Parameters
    ----------
    text : str
        Input an array of text / strings 
    
    CleverStop: set 
        Input a set of strings 

    max_w: int 
        Input an integer to indicate the maximum number of words included in the word cloud  
    
    Returns
    -------
    png image 
        Display the png image 
    
    Examples
    --------
    >>> CleverWordCloud(text, {"are", "my", "is"}, 200) 
    
    """
    from wordcloud import WordCloud
    import nltk
    if not isinstance(text, str):
        raise TypeError("Input text should be a string.")
   
    if not isinstance(CleverStop, set):
        raise TypeError("Input CleverStop should be a set.")
        
    if not isinstance(max_w, int):
        raise TypeError("Input max_w should be an integer.")
        
    for item in CleverStop:
        if not isinstance(item, str):
            raise TypeError("Each element of the CleverStop set should be a string.")
    
    wordcloud = WordCloud(stopwords=CleverStop, max_words=max_w).generate(text)
    image = wordcloud.to_image()
    image.show()  
    return image



# author: Adrianne Leung
# date: Jan 2022

def CleverStopwords(words):
    """
    A comprehensive list of English stopwords that allow adding more customized words.    
    
    Parameters
    ----------
    words : set of strings 
        Input a set of words that need to be included in the stopwords 
    
    Returns
    -------
    set of strings  
        The complete set of stopwords 
    
    Examples
    --------
    >>> sample_words = {'disney', 'paris'}
    >>> CleverStopwords(sample_words)
​
    """
    import nltk
    from nltk.corpus import stopwords
    
    # Download stopwords from NLTK library
    nltk.download('stopwords')
    
    # Test input variable type
    if not isinstance(words, set):
        raise TypeError("Input variable should be a set.")

    # Test data type of values of input variable
    for item in words:
        if not isinstance(item, str):
            raise TypeError("Each element of the input should be a string.")

    # NLTK English stopwords
    stopwords = set(stopwords.words("english"))

    try:
        nltk.download("stopwords")
    except:
        raise ImportError("Stopwords are not downloaded from NLTK.")

    new_stopwords = words
    
    # Check for unique new stopwords
    for w in new_stopwords:
        if w is not stopwords:
            # Add customised new words to the existing NLTK stopwords
            stopwords_all = stopwords.union(stopwords, new_stopwords)

    return stopwords_all



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['clevercloud']

package_data = \
{'': ['*']}

install_requires = \
['nltk>=3.6.7,<4.0.0',
 'pandas>=1.3.5,<2.0.0',
 'stem>=1.8.0,<2.0.0',
 'wordcloud>=1.8.1,<2.0.0']

setup_kwargs = {
    'name': 'clevercloud',
    'version': '0.1.0',
    'description': 'A package for creating clever word clouds',
    'long_description': '# clevercloud\n\nCreating meaningful word clouds! \n\n## Summary\n\nThis package is developed to serve as the one-step solution to create meaningful and visually appealing word clouds. To create meaningful word clouds, data scientists typically takes multiple steps to clean the data, such as removing stopwords, removing punctuation and digits, making the letters lower cases, conducting lemmatization and stemming. This package will help data scientists clean the data easily following the common practices and also allow to a meaningful word cloud with customized stopwords. \n\n## Functions\n\nThere are 4 functions in this package:\n\n-   `CleverClean` A preprocessor to convert all the letters to lower case and remove punctuations.\n\n-   `CleverLemStem` A preprocessor to conduct lemmatization and stemming on the text.\n\n-   `CleverStopwords` A comprehensive list of English stopwords that allow adding more customized words.\n\n-   `CleverWordCloud` As function to generate a meaningful word cloud that allows customized stopwords. \n\n## Fitting into the Python ecosystem\n\nPackages that have similar functions:\n\n- [WordCloud](https://github.com/amueller/word_cloud): a word count generator that emphasis more frequently used words from an array of strings and represents them in the form of an image. \n\nWhat we do differently: \n\n- Our aim is to improve on the pre-processing of strings before creating a wordcloud in order to make it more user specific and efficient.\n\n- Word cloud only eliminates limited amount of stopwords, but with our package we are giving users the opportunity to add more stopwords that cater to their analysis.\n\n- We are focused on removing as many redundant and duplicate words by setting strings to lower case, removing punctuation, lemmatizing and stemming the text. \n\n\n## Installation\n\n``` bash\n$ pip install clevercloud\n```\n\n## Usage\n\n`clevercloud` can be used to preprocess text and create a meaningful word cloud with customized stopwords\nas follows:\n\n```python\nfrom clevercloud.CleverClean import CleverClean\nfrom clevercloud.CleverLemStem import CleverLemStem\nfrom clevercloud.CleverStopwords import CleverStopwords\nfrom clevercloud.CleverWordCloud import CleverWordCloud\n\nimport pandas as pd\ntext = ["is is a feet feet crying beautiful123", "maximum feet RUNNING!!", "BEAUTIFUL feet beautiful crying"]\ntest_text = pd.Series(text) # input pandas series\n\nclean_text = CleverClean(test_text)\nfinal_text = CleverLemStem(clean_text)\nnew_stopwords = CleverStopwords({"foot", "cry"})\nWordCloud = CleverWordCloud(final_text, new_stopwords, max_w=3)\n\n```\n\n## Contributing\n\nContributors of the project: Amelia Tang, Arushi Ahuja, Victor Francis, Adrianne Leung\n\nInterested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.\n\n## License\n\n`clevercloud` was created by Amelia Tang, Arushi Ahuja, Victor Francis, Adrianne Leung. It is licensed under the terms of the MIT license.\n\n## Credits\n\n`clevercloud` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).\n',
    'author': 'Group_20',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



def CleverLemStem(text):
    """
    A preprocessor to conduct lemmatinzation and stemming on the text.   
    
    Parameters
    ----------
    text : str
        Input a string
    
    Returns
    -------
    str
        The lemmatized and stemmed string 
    
    Examples
    --------
    >>> sample_text = "maximum crying feet"
    >>> CleverLemStem(sample_text)
    "maxim cry foot"
    """
    # check the type of the imput 
    if not isinstance(text, str):
        raise TypeError("The input value should be a string.")
    
    # import packages 
    import nltk
    from nltk.stem import LancasterStemmer, WordNetLemmatizer
    from nltk.tokenize import RegexpTokenizer
    nltk.download('omw-1.4')
    nltk.download('wordnet')
    
    # lemmatization 
    tokenizer = RegexpTokenizer(r'\w+')
    tokenized_text = tokenizer.tokenize(text)
    lem = WordNetLemmatizer()
    lem_text = ' '.join([lem.lemmatize(i) for i in tokenized_text])
    
    # stemming 
    tokenized_lem_text = tokenizer.tokenize(lem_text)
    stemmer = LancasterStemmer()
    clean_text = ' '.join([stemmer.stem(i) for i in tokenized_lem_text]) 
    
    return clean_text
